package cn.com.infosec.asn1.isismtt.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERPrintableString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x500.DirectoryString;
import cn.com.infosec.asn1.x509.GeneralName;
import cn.com.infosec.asn1.x509.IssuerSerial;
import java.util.Enumeration;

public class ProcurationSyntax extends ASN1Encodable {
   private String country;
   private DirectoryString typeOfSubstitution;
   private GeneralName thirdPerson;
   private IssuerSerial certRef;

   public static ProcurationSyntax getInstance(Object obj) {
      if (obj != null && !(obj instanceof ProcurationSyntax)) {
         if (obj instanceof ASN1Sequence) {
            return new ProcurationSyntax((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (ProcurationSyntax)obj;
      }
   }

   private ProcurationSyntax(ASN1Sequence seq) {
      if (seq.size() >= 1 && seq.size() <= 3) {
         Enumeration var2 = seq.getObjects();

         while(var2.hasMoreElements()) {
            int var3;
            ASN1TaggedObject seq1;
            if ((var3 = (seq1 = ASN1TaggedObject.getInstance(var2.nextElement())).getTagNo()) != 1) {
               if (var3 != 2) {
                  if (var3 != 3) {
                     throw new IllegalArgumentException("Bad tag number: " + seq1.getTagNo());
                  }

                  DERObject seq2;
                  if ((seq2 = seq1.getObject()) instanceof ASN1TaggedObject) {
                     this.thirdPerson = GeneralName.getInstance(seq2);
                  } else {
                     this.certRef = IssuerSerial.getInstance(seq2);
                  }
               } else {
                  this.typeOfSubstitution = DirectoryString.getInstance(seq1, true);
               }
            } else {
               this.country = DERPrintableString.getInstance(seq1, true).getString();
            }
         }

      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public ProcurationSyntax(String country, DirectoryString typeOfSubstitution, IssuerSerial certRef) {
      this.country = country;
      this.typeOfSubstitution = typeOfSubstitution;
      this.thirdPerson = null;
      this.certRef = certRef;
   }

   public ProcurationSyntax(String country, DirectoryString typeOfSubstitution, GeneralName thirdPerson) {
      this.country = country;
      this.typeOfSubstitution = typeOfSubstitution;
      this.thirdPerson = thirdPerson;
      this.certRef = null;
   }

   public String getCountry() {
      return this.country;
   }

   public DirectoryString getTypeOfSubstitution() {
      return this.typeOfSubstitution;
   }

   public GeneralName getThirdPerson() {
      return this.thirdPerson;
   }

   public IssuerSerial getCertRef() {
      return this.certRef;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DERTaggedObject var10001;
      String var2;
      DERTaggedObject var3;
      if ((var2 = this.country) != null) {
         var10001 = var3 = new DERTaggedObject;
         DERPrintableString var4;
         var4 = new DERPrintableString.<init>(var2, true);
         var10001.<init>(true, 1, var4);
         var1.add(var3);
      }

      DirectoryString var7;
      if ((var7 = this.typeOfSubstitution) != null) {
         var3 = new DERTaggedObject.<init>(true, 2, var7);
         var1.add(var3);
      }

      GeneralName var8;
      if ((var8 = this.thirdPerson) != null) {
         DERTaggedObject var5;
         var5 = new DERTaggedObject.<init>(true, 3, var8);
         var1.add(var5);
      } else {
         DERTaggedObject var9;
         var10001 = var9 = new DERTaggedObject;
         IssuerSerial var6 = this.certRef;
         var10001.<init>(true, 3, var6);
         var1.add(var9);
      }

      return new DERSequence(var1);
   }
}
